@@ -15,11 +15,18 @@ fn use_fn(){
                 "hulkfolder/templates" ,
             ];
 let a = tasks::create_dir_structure::
-run(paths_list);
+run(&paths_list);
 assert!(a.is_ok());
     //====== tests
     assert_eq!(true,brown::path_exists("./data"));
     assert_eq!(true,brown::path_exists("./data_with"));
     assert_eq!(true,brown::path_exists("./site/images"));
-    assert_eq!(true,brown::path_exists("./hulkfolder/templates"));   
+    assert_eq!(true,brown::path_exists("./hulkfolder/templates")); 
+    
+    brown::remove_dir_brute("./data");
+    brown::remove_dir_brute("./data_with");
+    brown::remove_dir_brute("./site/images");
+    brown::remove_dir_brute("./hulkfolder/templates"); 
+    brown::remove_dir_brute("./hulkfolder"); 
+     
 }
\ No newline at end of file
